/* QQQ - Low-code Application Framework for Engineers.
 * Copyright (C) 2021-2022.  Kingsrook, LLC
 * 651 N Broad St Ste 205 # 6917 | Middletown DE 19709 | United States
 * contact@kingsrook.com
 * https://github.com/Kingsrook/
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

import {FC, forwardRef} from "react";
import MDBox from "components/MDBox";
import MDTypography from "components/MDTypography";

// declaring props types for MDBadgeDot
interface Props
{
   variant?: "gradient" | "contained";
   color?: string;
   size?: "xs" | "sm" | "md" | "lg";
   badgeContent: string;
   font?:
      | {
      color: string;
      weight: string;
   }
      | any;

   [key: string]: any;
}

const MDBadgeDot: FC<Props> = forwardRef(
   ({variant, color, size, badgeContent, font = {}, ...rest}, ref) =>
   {
      let finalSize;
      let fontSize: any;
      let padding;

      if (size === "sm")
      {
         finalSize = "0.5rem";
         fontSize = "caption";
         padding = "0.45em 0.775em";
      }
      else if (size === "lg")
      {
         finalSize = "0.625rem";
         fontSize = "body2";
         padding = "0.85em 1.375em";
      }
      else if (size === "md")
      {
         finalSize = "0.5rem";
         fontSize = "button";
         padding = "0.65em 1em";
      }
      else
      {
         finalSize = "0.375rem";
         fontSize = "caption";
         padding = "0.45em 0.775em";
      }

      const validColors = [
         "primary",
         "secondary",
         "info",
         "success",
         "warning",
         "error",
         "light",
         "dark",
      ];

      const validColorIndex = validColors.findIndex((el) => el === color);

      return (
         <MDBox ref={ref} display="flex" alignItems="center" p={padding} {...rest}>
            <MDBox
               component="i"
               display="inline-block"
               width={finalSize}
               height={finalSize}
               borderRadius="50%"
               bgColor={validColors[validColorIndex]}
               variant={variant}
               mr={1}
            />
            <MDTypography
               variant={fontSize}
               fontWeight={font.weight ? font.weight : "regular"}
               color={font.color ? font.color : "dark"}
               sx={{lineHeight: 0}}
            >
               {badgeContent}
            </MDTypography>
         </MDBox>
      );
   }
);

// Declaring default props for MDBadgeDot
MDBadgeDot.defaultProps = {
   variant: "contained",
   color: "info",
   size: "xs",
   font: {},
};

export default MDBadgeDot;
